/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.office.rt2.core.control;

import org.eclipse.microprofile.health.HealthCheckResponse;
import com.openexchange.office.rt2.protocol.RT2Message;

public interface IRT2NodeHealthManager {

    public HealthCheckResponse checkHealth();

    public void crashedNodeDocCleanupCompleted(final RT2Message aCleanupOrderCompletedMsg);

    public void startLocalNodeDocCleanup(final RT2Message aCleanupOrderMsg);

    public void checkCorrectNodeShutdown(final String nodeUUID);
}
